# Checks
Organisation, structure, content, reasoning and support information for all Checks in Sek.

# Clouds
One folder per supported Cloud.

Example: `aws/`.

# Resources
One folder per supported Resource under that Cloud which corresponds to a set of Checks.

Example: `aws/eks/`.
